# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/desired_state/maestro/maestro.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.desired_state.model import desired_state_pb2 as prodvana_dot_desired__state_dot_model_dot_desired__state__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,prodvana/desired_state/maestro/maestro.proto\x12\x1eprodvana.desired_state.maestro\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a\x30prodvana/desired_state/model/desired_state.proto\x1a\x1aprodvana/object/meta.proto\"U\n\rMaestroConfig\x12\x44\n\x08strategy\x18\x01 \x01(\x0e\x32(.prodvana.desired_state.maestro.StrategyB\x08\xfa\x42\x05\x82\x01\x02 \x00\"\xb4\x03\n\x14MaestroReleaseConfig\x12;\n\tentity_id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x45\n\x0emaestro_config\x18\x02 \x01(\x0b\x32-.prodvana.desired_state.maestro.MaestroConfig\x12@\n\x13input_desired_state\x18\x05 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x43\n\x16\x63ompiled_desired_state\x18\x03 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12Y\n\x1aset_desired_state_metadata\x18\x06 \x01(\x0b\x32\x35.prodvana.desired_state.model.SetDesiredStateMetadata\"\xf0\x04\n\x13MaestroReleaseState\x12\x36\n\x06status\x18\x01 \x01(\x0e\x32&.prodvana.desired_state.maestro.Status\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12q\n\x18release_channel_statuses\x18\x03 \x03(\x0b\x32O.prodvana.desired_state.maestro.MaestroReleaseState.ReleaseChannelStatusesEntry\x12m\n\x16release_channel_states\x18\x04 \x03(\x0b\x32M.prodvana.desired_state.maestro.MaestroReleaseState.ReleaseChannelStatesEntry\x12$\n\x1cshared_root_desired_state_id\x18\x05 \x01(\t\x1a\x65\n\x1bReleaseChannelStatusesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0e\x32&.prodvana.desired_state.maestro.Status:\x02\x38\x01\x1aw\n\x19ReleaseChannelStatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.prodvana.desired_state.maestro.MaestroReleaseChannelState:\x02\x38\x01\"\xa0\x01\n\x1aMaestroReleaseChannelState\x12\x36\n\x06status\x18\x01 \x01(\x0e\x32&.prodvana.desired_state.maestro.Status\x12\x18\n\x10\x64\x65sired_state_id\x18\x02 \x01(\t\x12\x11\n\tentity_id\x18\x03 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x04 \x01(\t\"\xc5\x01\n\x0eMaestroRelease\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x44\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x34.prodvana.desired_state.maestro.MaestroReleaseConfig\x12\x42\n\x05state\x18\x03 \x01(\x0b\x32\x33.prodvana.desired_state.maestro.MaestroReleaseState*b\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\r\n\tSUCCEEDED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0b\n\x07SKIPPED\x10\x05*^\n\x08Strategy\x12\x14\n\x10UNKNOWN_STRATEGY\x10\x00\x12\x11\n\rRELEASE_TRAIN\x10\x02\x12\x14\n\x10MAESTRO_DISABLED\x10\x03\x12\r\n\tIMMEDIATE\x10\x04\"\x04\x08\x01\x10\x01\x42ZZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/maestrob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.desired_state.maestro.maestro_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/maestro'
  _MAESTROCONFIG.fields_by_name['strategy']._options = None
  _MAESTROCONFIG.fields_by_name['strategy']._serialized_options = b'\372B\005\202\001\002 \000'
  _MAESTRORELEASESTATE_RELEASECHANNELSTATUSESENTRY._options = None
  _MAESTRORELEASESTATE_RELEASECHANNELSTATUSESENTRY._serialized_options = b'8\001'
  _MAESTRORELEASESTATE_RELEASECHANNELSTATESENTRY._options = None
  _MAESTRORELEASESTATE_RELEASECHANNELSTATESENTRY._serialized_options = b'8\001'
  _globals['_STATUS']._serialized_start=1732
  _globals['_STATUS']._serialized_end=1830
  _globals['_STRATEGY']._serialized_start=1832
  _globals['_STRATEGY']._serialized_end=1926
  _globals['_MAESTROCONFIG']._serialized_start=216
  _globals['_MAESTROCONFIG']._serialized_end=301
  _globals['_MAESTRORELEASECONFIG']._serialized_start=304
  _globals['_MAESTRORELEASECONFIG']._serialized_end=740
  _globals['_MAESTRORELEASESTATE']._serialized_start=743
  _globals['_MAESTRORELEASESTATE']._serialized_end=1367
  _globals['_MAESTRORELEASESTATE_RELEASECHANNELSTATUSESENTRY']._serialized_start=1145
  _globals['_MAESTRORELEASESTATE_RELEASECHANNELSTATUSESENTRY']._serialized_end=1246
  _globals['_MAESTRORELEASESTATE_RELEASECHANNELSTATESENTRY']._serialized_start=1248
  _globals['_MAESTRORELEASESTATE_RELEASECHANNELSTATESENTRY']._serialized_end=1367
  _globals['_MAESTRORELEASECHANNELSTATE']._serialized_start=1370
  _globals['_MAESTRORELEASECHANNELSTATE']._serialized_end=1530
  _globals['_MAESTRORELEASE']._serialized_start=1533
  _globals['_MAESTRORELEASE']._serialized_end=1730
# @@protoc_insertion_point(module_scope)
