"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.object.manager_pb2

class ObjectManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    QueryObjects: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.object.manager_pb2.QueryObjectReq,
        prodvana.proto.prodvana.object.manager_pb2.QueryObjectResp,
    ]
    GetLabels: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.object.manager_pb2.GetLabelsReq,
        prodvana.proto.prodvana.object.manager_pb2.GetLabelsResp,
    ]

class ObjectManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def QueryObjects(
        self,
        request: prodvana.proto.prodvana.object.manager_pb2.QueryObjectReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.object.manager_pb2.QueryObjectResp: ...
    @abc.abstractmethod
    def GetLabels(
        self,
        request: prodvana.proto.prodvana.object.manager_pb2.GetLabelsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.object.manager_pb2.GetLabelsResp: ...

def add_ObjectManagerServicer_to_server(servicer: ObjectManagerServicer, server: grpc.Server) -> None: ...
