# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vtproto/ext.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11vtproto/ext.proto\x12\x07vtproto\x1a google/protobuf/descriptor.proto:2\n\x07mempool\x12\x1f.google.protobuf.MessageOptions\x18\xe5\xf4\x03 \x01(\x08:;\n\x12unstable_for_equal\x12\x1d.google.protobuf.FieldOptions\x18\xe5\xf4\x03 \x01(\x08\x42I\n\x13\x63om.google.protobufB\x07VTProtoZ)github.com/planetscale/vtprotobuf/vtproto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vtproto.ext_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(mempool)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(unstable_for_equal)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.google.protobufB\007VTProtoZ)github.com/planetscale/vtprotobuf/vtproto'
# @@protoc_insertion_point(module_scope)
