# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/fly/fly_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import kubernetes_config_pb2 as prodvana_dot_common__config_dot_kubernetes__config__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprodvana/fly/fly_config.proto\x12\x0cprodvana.fly\x1a.prodvana/common_config/kubernetes_config.proto\x1a\x17validate/validate.proto\"\xbc\x01\n\tFlyConfig\x12\x1a\n\x07inlined\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12>\n\x05local\x18\x02 \x01(\x0b\x32#.prodvana.common_config.LocalConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12@\n\x06remote\x18\x03 \x01(\x0b\x32$.prodvana.common_config.RemoteConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x42\x11\n\ntoml_oneof\x12\x03\xf8\x42\x01\x42HZFgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/flyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.fly.fly_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZFgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/fly'
  _FLYCONFIG.oneofs_by_name['toml_oneof']._options = None
  _FLYCONFIG.oneofs_by_name['toml_oneof']._serialized_options = b'\370B\001'
  _FLYCONFIG.fields_by_name['inlined']._options = None
  _FLYCONFIG.fields_by_name['inlined']._serialized_options = b'\372B\004r\002\020\001'
  _FLYCONFIG.fields_by_name['local']._options = None
  _FLYCONFIG.fields_by_name['local']._serialized_options = b'\372B\005\212\001\002\020\001'
  _FLYCONFIG.fields_by_name['remote']._options = None
  _FLYCONFIG.fields_by_name['remote']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_FLYCONFIG']._serialized_start=121
  _globals['_FLYCONFIG']._serialized_end=309
# @@protoc_insertion_point(module_scope)
