# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.workflow import workflow_manager_pb2 as prodvana_dot_workflow_dot_workflow__manager__pb2


class WorkflowManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListIntegrations = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/ListIntegrations',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsResp.FromString,
                )
        self.DeleteIntegration = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/DeleteIntegration',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationResp.FromString,
                )
        self.CreateContainerRegistryIntegration = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/CreateContainerRegistryIntegration',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationRes.FromString,
                )
        self.DeleteContainerRegistryIntegration = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/DeleteContainerRegistryIntegration',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationResp.FromString,
                )
        self.ListContainerRegistryIntegrations = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/ListContainerRegistryIntegrations',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsResp.FromString,
                )
        self.GetContainerRegistryIntegration = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetContainerRegistryIntegration',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationResp.FromString,
                )
        self.GetServiceImageInfo = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetServiceImageInfo',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoResp.FromString,
                )
        self.GetContainerRegistryImages = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetContainerRegistryImages',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesRes.FromString,
                )
        self.ListTrackedImageRepositories = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/ListTrackedImageRepositories',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesResp.FromString,
                )
        self.GetTrackedImageRepository = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetTrackedImageRepository',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryResp.FromString,
                )
        self.TrackImageRepositories = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/TrackImageRepositories',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesResp.FromString,
                )
        self.StopTrackingImageRepository = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/StopTrackingImageRepository',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryResp.FromString,
                )
        self.GetProgramDefaults = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetProgramDefaults',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsResp.FromString,
                )
        self.GetImageCommitInfo = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetImageCommitInfo',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoResp.FromString,
                )
        self.InstallSlack = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/InstallSlack',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackResp.FromString,
                )
        self.UninstallSlack = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UninstallSlack',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackResp.FromString,
                )
        self.GetInstallSlackUrl = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetInstallSlackUrl',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlResp.FromString,
                )
        self.InstallPagerDuty = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/InstallPagerDuty',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyResp.FromString,
                )
        self.GetInstallPagerDutyUrl = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetInstallPagerDutyUrl',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlResp.FromString,
                )
        self.UninstallPagerDuty = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UninstallPagerDuty',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyResp.FromString,
                )
        self.GetGrafanaInstallation = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetGrafanaInstallation',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationResp.FromString,
                )
        self.InstallGrafana = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/InstallGrafana',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaResp.FromString,
                )
        self.UninstallGrafana = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UninstallGrafana',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaResp.FromString,
                )
        self.ListHoneycombEnvironments = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/ListHoneycombEnvironments',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsResp.FromString,
                )
        self.AddHoneycombEnvironment = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/AddHoneycombEnvironment',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentResp.FromString,
                )
        self.UpdateHoneycombEnvironment = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UpdateHoneycombEnvironment',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentResp.FromString,
                )
        self.DeleteHoneycombEnvironment = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/DeleteHoneycombEnvironment',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentResp.FromString,
                )
        self.UninstallHoneycomb = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UninstallHoneycomb',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombResp.FromString,
                )
        self.GetInstallGitHubUrl = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetInstallGitHubUrl',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlResp.FromString,
                )
        self.CreateGitHubApp = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/CreateGitHubApp',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppResp.FromString,
                )
        self.InstallGitHub = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/InstallGitHub',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubResp.FromString,
                )
        self.ListRepoCommits = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/ListRepoCommits',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsResp.FromString,
                )
        self.GetCommitInfo = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetCommitInfo',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoResp.FromString,
                )
        self.InstallLast9 = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/InstallLast9',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Req.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Resp.FromString,
                )
        self.UninstallLast9 = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UninstallLast9',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Req.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Resp.FromString,
                )
        self.GetLast9Installation = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetLast9Installation',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationResp.FromString,
                )


class WorkflowManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListIntegrations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContainerRegistryIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteContainerRegistryIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListContainerRegistryIntegrations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContainerRegistryIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceImageInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContainerRegistryImages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTrackedImageRepositories(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTrackedImageRepository(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TrackImageRepositories(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopTrackingImageRepository(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProgramDefaults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImageCommitInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstallSlack(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UninstallSlack(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstallSlackUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstallPagerDuty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstallPagerDutyUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UninstallPagerDuty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGrafanaInstallation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstallGrafana(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UninstallGrafana(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListHoneycombEnvironments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddHoneycombEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateHoneycombEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteHoneycombEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UninstallHoneycomb(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstallGitHubUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateGitHubApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstallGitHub(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRepoCommits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommitInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstallLast9(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UninstallLast9(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLast9Installation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkflowManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListIntegrations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIntegrations,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsResp.SerializeToString,
            ),
            'DeleteIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIntegration,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationResp.SerializeToString,
            ),
            'CreateContainerRegistryIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContainerRegistryIntegration,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationRes.SerializeToString,
            ),
            'DeleteContainerRegistryIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteContainerRegistryIntegration,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationResp.SerializeToString,
            ),
            'ListContainerRegistryIntegrations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListContainerRegistryIntegrations,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsResp.SerializeToString,
            ),
            'GetContainerRegistryIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContainerRegistryIntegration,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationResp.SerializeToString,
            ),
            'GetServiceImageInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceImageInfo,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoResp.SerializeToString,
            ),
            'GetContainerRegistryImages': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContainerRegistryImages,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesRes.SerializeToString,
            ),
            'ListTrackedImageRepositories': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTrackedImageRepositories,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesResp.SerializeToString,
            ),
            'GetTrackedImageRepository': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTrackedImageRepository,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryResp.SerializeToString,
            ),
            'TrackImageRepositories': grpc.unary_unary_rpc_method_handler(
                    servicer.TrackImageRepositories,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesResp.SerializeToString,
            ),
            'StopTrackingImageRepository': grpc.unary_unary_rpc_method_handler(
                    servicer.StopTrackingImageRepository,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryResp.SerializeToString,
            ),
            'GetProgramDefaults': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProgramDefaults,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsResp.SerializeToString,
            ),
            'GetImageCommitInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImageCommitInfo,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoResp.SerializeToString,
            ),
            'InstallSlack': grpc.unary_unary_rpc_method_handler(
                    servicer.InstallSlack,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackResp.SerializeToString,
            ),
            'UninstallSlack': grpc.unary_unary_rpc_method_handler(
                    servicer.UninstallSlack,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackResp.SerializeToString,
            ),
            'GetInstallSlackUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstallSlackUrl,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlResp.SerializeToString,
            ),
            'InstallPagerDuty': grpc.unary_unary_rpc_method_handler(
                    servicer.InstallPagerDuty,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyResp.SerializeToString,
            ),
            'GetInstallPagerDutyUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstallPagerDutyUrl,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlResp.SerializeToString,
            ),
            'UninstallPagerDuty': grpc.unary_unary_rpc_method_handler(
                    servicer.UninstallPagerDuty,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyResp.SerializeToString,
            ),
            'GetGrafanaInstallation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGrafanaInstallation,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationResp.SerializeToString,
            ),
            'InstallGrafana': grpc.unary_unary_rpc_method_handler(
                    servicer.InstallGrafana,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaResp.SerializeToString,
            ),
            'UninstallGrafana': grpc.unary_unary_rpc_method_handler(
                    servicer.UninstallGrafana,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaResp.SerializeToString,
            ),
            'ListHoneycombEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListHoneycombEnvironments,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsResp.SerializeToString,
            ),
            'AddHoneycombEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.AddHoneycombEnvironment,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentResp.SerializeToString,
            ),
            'UpdateHoneycombEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateHoneycombEnvironment,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentResp.SerializeToString,
            ),
            'DeleteHoneycombEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteHoneycombEnvironment,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentResp.SerializeToString,
            ),
            'UninstallHoneycomb': grpc.unary_unary_rpc_method_handler(
                    servicer.UninstallHoneycomb,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombResp.SerializeToString,
            ),
            'GetInstallGitHubUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstallGitHubUrl,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlResp.SerializeToString,
            ),
            'CreateGitHubApp': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGitHubApp,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppResp.SerializeToString,
            ),
            'InstallGitHub': grpc.unary_unary_rpc_method_handler(
                    servicer.InstallGitHub,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubResp.SerializeToString,
            ),
            'ListRepoCommits': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRepoCommits,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsResp.SerializeToString,
            ),
            'GetCommitInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCommitInfo,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoResp.SerializeToString,
            ),
            'InstallLast9': grpc.unary_unary_rpc_method_handler(
                    servicer.InstallLast9,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Req.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Resp.SerializeToString,
            ),
            'UninstallLast9': grpc.unary_unary_rpc_method_handler(
                    servicer.UninstallLast9,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Req.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Resp.SerializeToString,
            ),
            'GetLast9Installation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLast9Installation,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.workflow.WorkflowManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WorkflowManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListIntegrations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/ListIntegrations',
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/DeleteIntegration',
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContainerRegistryIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/CreateContainerRegistryIntegration',
            prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteContainerRegistryIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/DeleteContainerRegistryIntegration',
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListContainerRegistryIntegrations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/ListContainerRegistryIntegrations',
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContainerRegistryIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetContainerRegistryIntegration',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceImageInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetServiceImageInfo',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContainerRegistryImages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetContainerRegistryImages',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTrackedImageRepositories(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/ListTrackedImageRepositories',
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTrackedImageRepository(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetTrackedImageRepository',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TrackImageRepositories(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/TrackImageRepositories',
            prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopTrackingImageRepository(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/StopTrackingImageRepository',
            prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProgramDefaults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetProgramDefaults',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImageCommitInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetImageCommitInfo',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstallSlack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/InstallSlack',
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UninstallSlack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UninstallSlack',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstallSlackUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetInstallSlackUrl',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstallPagerDuty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/InstallPagerDuty',
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstallPagerDutyUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetInstallPagerDutyUrl',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UninstallPagerDuty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UninstallPagerDuty',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGrafanaInstallation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetGrafanaInstallation',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstallGrafana(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/InstallGrafana',
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UninstallGrafana(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UninstallGrafana',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListHoneycombEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/ListHoneycombEnvironments',
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddHoneycombEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/AddHoneycombEnvironment',
            prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateHoneycombEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UpdateHoneycombEnvironment',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteHoneycombEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/DeleteHoneycombEnvironment',
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UninstallHoneycomb(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UninstallHoneycomb',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstallGitHubUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetInstallGitHubUrl',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateGitHubApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/CreateGitHubApp',
            prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstallGitHub(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/InstallGitHub',
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRepoCommits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/ListRepoCommits',
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCommitInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetCommitInfo',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstallLast9(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/InstallLast9',
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Req.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Resp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UninstallLast9(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UninstallLast9',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Req.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Resp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLast9Installation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetLast9Installation',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
