# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/capability/capability.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.pipelines import pipelines_pb2 as prodvana_dot_pipelines_dot_pipelines__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$prodvana/capability/capability.proto\x12\x13prodvana.capability\x1a prodvana/common_config/env.proto\x1a\"prodvana/pipelines/pipelines.proto\x1a\x17validate/validate.proto\"\xdb\x01\n!PerReleaseChannelCapabilityConfig\x12 \n\x0frelease_channel\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12@\n\x07inlined\x18\x02 \x01(\x0b\x32-.prodvana.capability.CapabilityInstanceConfigH\x00\x12\x39\n\x03ref\x18\x03 \x01(\x0b\x32*.prodvana.capability.CapabilityInstanceRefH\x00\x42\x17\n\x10\x64\x65\x66inition_oneof\x12\x03\xf8\x42\x01\"\x8d\x01\n\x10\x43\x61pabilityConfig\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x62\n\x13per_release_channel\x18\x02 \x03(\x0b\x32\x36.prodvana.capability.PerReleaseChannelCapabilityConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\"\xa5\x02\n\x18\x43\x61pabilityInstanceConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12l\n\x03\x65nv\x18\x02 \x03(\x0b\x32\x36.prodvana.capability.CapabilityInstanceConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12?\n\x0epre_push_tasks\x18\x03 \x03(\x0b\x32\x18.prodvana.pipelines.TaskB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\".\n\x15\x43\x61pabilityInstanceRef\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42OZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/capabilityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.capability.capability_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/capability'
  _PERRELEASECHANNELCAPABILITYCONFIG.oneofs_by_name['definition_oneof']._options = None
  _PERRELEASECHANNELCAPABILITYCONFIG.oneofs_by_name['definition_oneof']._serialized_options = b'\370B\001'
  _PERRELEASECHANNELCAPABILITYCONFIG.fields_by_name['release_channel']._options = None
  _PERRELEASECHANNELCAPABILITYCONFIG.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _CAPABILITYCONFIG.fields_by_name['name']._options = None
  _CAPABILITYCONFIG.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CAPABILITYCONFIG.fields_by_name['per_release_channel']._options = None
  _CAPABILITYCONFIG.fields_by_name['per_release_channel']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _CAPABILITYINSTANCECONFIG_ENVENTRY._options = None
  _CAPABILITYINSTANCECONFIG_ENVENTRY._serialized_options = b'8\001'
  _CAPABILITYINSTANCECONFIG.fields_by_name['env']._options = None
  _CAPABILITYINSTANCECONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _CAPABILITYINSTANCECONFIG.fields_by_name['pre_push_tasks']._options = None
  _CAPABILITYINSTANCECONFIG.fields_by_name['pre_push_tasks']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _CAPABILITYINSTANCEREF.fields_by_name['name']._options = None
  _CAPABILITYINSTANCEREF.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_PERRELEASECHANNELCAPABILITYCONFIG']._serialized_start=157
  _globals['_PERRELEASECHANNELCAPABILITYCONFIG']._serialized_end=376
  _globals['_CAPABILITYCONFIG']._serialized_start=379
  _globals['_CAPABILITYCONFIG']._serialized_end=520
  _globals['_CAPABILITYINSTANCECONFIG']._serialized_start=523
  _globals['_CAPABILITYINSTANCECONFIG']._serialized_end=816
  _globals['_CAPABILITYINSTANCECONFIG_ENVENTRY']._serialized_start=740
  _globals['_CAPABILITYINSTANCECONFIG_ENVENTRY']._serialized_end=816
  _globals['_CAPABILITYINSTANCEREF']._serialized_start=818
  _globals['_CAPABILITYINSTANCEREF']._serialized_end=864
# @@protoc_insertion_point(module_scope)
