"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.pvn_wrapper.job_manager_pb2

class JobManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ReportJobResult: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.pvn_wrapper.job_manager_pb2.ReportJobResultReq,
        prodvana.proto.prodvana.pvn_wrapper.job_manager_pb2.ReportJobResultResp,
    ]

class JobManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ReportJobResult(
        self,
        request: prodvana.proto.prodvana.pvn_wrapper.job_manager_pb2.ReportJobResultReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.pvn_wrapper.job_manager_pb2.ReportJobResultResp: ...

def add_JobManagerServicer_to_server(servicer: JobManagerServicer, server: grpc.Server) -> None: ...
