# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/managed_resource/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'prodvana/managed_resource/manager.proto\x12\x19prodvana.managed_resource\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd4\x03\n\x16\x43onfigureK8sClusterReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12S\n\x0bgcp_options\x18\x02 \x01(\x0b\x32<.prodvana.managed_resource.ConfigureK8sClusterReq.GcpOptionsH\x00\x12S\n\x0b\x65ks_options\x18\x07 \x01(\x0b\x32<.prodvana.managed_resource.ConfigureK8sClusterReq.EKSOptionsH\x00\x12\x15\n\rinstance_type\x18\x03 \x01(\t\x12\x16\n\x0enodepool_zones\x18\x04 \x03(\t\x12\x1b\n\x13node_count_per_zone\x18\x05 \x01(\x05\x12\x0e\n\x06region\x18\x06 \x01(\t\x1a\x32\n\nGcpOptions\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x13\n\x0b\x63redentials\x18\x02 \x01(\t\x1aZ\n\nEKSOptions\x12\x12\n\naccess_key\x18\x01 \x01(\t\x12\x12\n\nsecret_key\x18\x02 \x01(\t\x12\x12\n\naccount_id\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\tB\x16\n\x14\x63loud_provider_oneof\"w\n\x17\x43onfigureK8sClusterResp\x12\n\n\x02id\x18\x04 \x01(\t\x12*\n\x06run_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61rchive_url\x18\x03 \x01(\t\"\xbb\x02\n\x0fManagedResource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x42\n\nlatest_run\x18\x04 \x01(\x0b\x32..prodvana.managed_resource.ManagedResource.Run\x1a\xbb\x01\n\x03Run\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x10\n\x08terminal\x18\x03 \x01(\x08\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x06 \x01(\t\"1\n\x15GetManagedResourceReq\x12\x18\n\x10managed_resource\x18\x01 \x01(\t\"^\n\x16GetManagedResourceResp\x12\x44\n\x10managed_resource\x18\x01 \x01(\x0b\x32*.prodvana.managed_resource.ManagedResource\"\x19\n\x17ListManagedResourcesReq\"a\n\x18ListManagedResourcesResp\x12\x45\n\x11managed_resources\x18\x01 \x03(\x0b\x32*.prodvana.managed_resource.ManagedResource\":\n\rGetArchiveReq\x12\x18\n\x10managed_resource\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x1f\n\x0eGetArchiveResp\x12\r\n\x05\x62ytes\x18\x01 \x01(\x0c\"v\n\x0eMarkRunDoneReq\x12\x18\n\x10managed_resource\x18\x01 \x01(\t\x12*\n\x06run_id\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tsucceeded\x18\x03 \x01(\x08\x12\x0b\n\x03msg\x18\x04 \x01(\t\"\x11\n\x0fMarkRunDoneResp\"4\n\x18\x44\x65leteManagedResourceReq\x12\x18\n\x10managed_resource\x18\x01 \x01(\t\"S\n\x19\x44\x65leteManagedResourceResp\x12\n\n\x02id\x18\x01 \x01(\t\x12*\n\x06run_id\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xf3\x07\n\x0fResourceManager\x12\xac\x01\n\x13\x43onfigureK8sCluster\x12\x31.prodvana.managed_resource.ConfigureK8sClusterReq\x1a\x32.prodvana.managed_resource.ConfigureK8sClusterResp\".\x82\xd3\xe4\x93\x02(\"#/v1/managed_resources/k8s/configure:\x01*\x12\xad\x01\n\x12GetManagedResource\x12\x30.prodvana.managed_resource.GetManagedResourceReq\x1a\x31.prodvana.managed_resource.GetManagedResourceResp\"2\x82\xd3\xe4\x93\x02,\x12*/v1/managed_resources/{managed_resource=*}\x12\x9e\x01\n\x14ListManagedResources\x12\x32.prodvana.managed_resource.ListManagedResourcesReq\x1a\x33.prodvana.managed_resource.ListManagedResourcesResp\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/managed_resources\x12\xb7\x01\n\nGetArchive\x12(.prodvana.managed_resource.GetArchiveReq\x1a).prodvana.managed_resource.GetArchiveResp\"R\x82\xd3\xe4\x93\x02L\x12J/v1/managed_resources/{managed_resource=*}/archive/archive/archive/archive0\x01\x12\xbd\x01\n\x15\x44\x65leteManagedResource\x12\x33.prodvana.managed_resource.DeleteManagedResourceReq\x1a\x34.prodvana.managed_resource.DeleteManagedResourceResp\"9\x82\xd3\xe4\x93\x02\x33*1/v1/managed_resources/{managed_resource=*}/delete\x12\x66\n\x0bMarkRunDone\x12).prodvana.managed_resource.MarkRunDoneReq\x1a*.prodvana.managed_resource.MarkRunDoneResp\"\x00\x42UZSgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/managed_resourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.managed_resource.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZSgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/managed_resource'
  _RESOURCEMANAGER.methods_by_name['ConfigureK8sCluster']._options = None
  _RESOURCEMANAGER.methods_by_name['ConfigureK8sCluster']._serialized_options = b'\202\323\344\223\002(\"#/v1/managed_resources/k8s/configure:\001*'
  _RESOURCEMANAGER.methods_by_name['GetManagedResource']._options = None
  _RESOURCEMANAGER.methods_by_name['GetManagedResource']._serialized_options = b'\202\323\344\223\002,\022*/v1/managed_resources/{managed_resource=*}'
  _RESOURCEMANAGER.methods_by_name['ListManagedResources']._options = None
  _RESOURCEMANAGER.methods_by_name['ListManagedResources']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/managed_resources'
  _RESOURCEMANAGER.methods_by_name['GetArchive']._options = None
  _RESOURCEMANAGER.methods_by_name['GetArchive']._serialized_options = b'\202\323\344\223\002L\022J/v1/managed_resources/{managed_resource=*}/archive/archive/archive/archive'
  _RESOURCEMANAGER.methods_by_name['DeleteManagedResource']._options = None
  _RESOURCEMANAGER.methods_by_name['DeleteManagedResource']._serialized_options = b'\202\323\344\223\0023*1/v1/managed_resources/{managed_resource=*}/delete'
  _globals['_CONFIGUREK8SCLUSTERREQ']._serialized_start=134
  _globals['_CONFIGUREK8SCLUSTERREQ']._serialized_end=602
  _globals['_CONFIGUREK8SCLUSTERREQ_GCPOPTIONS']._serialized_start=436
  _globals['_CONFIGUREK8SCLUSTERREQ_GCPOPTIONS']._serialized_end=486
  _globals['_CONFIGUREK8SCLUSTERREQ_EKSOPTIONS']._serialized_start=488
  _globals['_CONFIGUREK8SCLUSTERREQ_EKSOPTIONS']._serialized_end=578
  _globals['_CONFIGUREK8SCLUSTERRESP']._serialized_start=604
  _globals['_CONFIGUREK8SCLUSTERRESP']._serialized_end=723
  _globals['_MANAGEDRESOURCE']._serialized_start=726
  _globals['_MANAGEDRESOURCE']._serialized_end=1041
  _globals['_MANAGEDRESOURCE_RUN']._serialized_start=854
  _globals['_MANAGEDRESOURCE_RUN']._serialized_end=1041
  _globals['_GETMANAGEDRESOURCEREQ']._serialized_start=1043
  _globals['_GETMANAGEDRESOURCEREQ']._serialized_end=1092
  _globals['_GETMANAGEDRESOURCERESP']._serialized_start=1094
  _globals['_GETMANAGEDRESOURCERESP']._serialized_end=1188
  _globals['_LISTMANAGEDRESOURCESREQ']._serialized_start=1190
  _globals['_LISTMANAGEDRESOURCESREQ']._serialized_end=1215
  _globals['_LISTMANAGEDRESOURCESRESP']._serialized_start=1217
  _globals['_LISTMANAGEDRESOURCESRESP']._serialized_end=1314
  _globals['_GETARCHIVEREQ']._serialized_start=1316
  _globals['_GETARCHIVEREQ']._serialized_end=1374
  _globals['_GETARCHIVERESP']._serialized_start=1376
  _globals['_GETARCHIVERESP']._serialized_end=1407
  _globals['_MARKRUNDONEREQ']._serialized_start=1409
  _globals['_MARKRUNDONEREQ']._serialized_end=1527
  _globals['_MARKRUNDONERESP']._serialized_start=1529
  _globals['_MARKRUNDONERESP']._serialized_end=1546
  _globals['_DELETEMANAGEDRESOURCEREQ']._serialized_start=1548
  _globals['_DELETEMANAGEDRESOURCEREQ']._serialized_end=1600
  _globals['_DELETEMANAGEDRESOURCERESP']._serialized_start=1602
  _globals['_DELETEMANAGEDRESOURCERESP']._serialized_end=1685
  _globals['_RESOURCEMANAGER']._serialized_start=1688
  _globals['_RESOURCEMANAGER']._serialized_end=2699
# @@protoc_insertion_point(module_scope)
