"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.capability.capability_pb2
import prodvana.proto.prodvana.common_config.notification_pb2
import prodvana.proto.prodvana.release_channel.release_channel_config_pb2
import prodvana.proto.prodvana.workflow.integration_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AnnotationsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Last9(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DATA_SOURCE_FIELD_NUMBER: builtins.int
        data_source: builtins.str
        def __init__(
            self,
            *,
            data_source: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> None: ...

    LAST9_FIELD_NUMBER: builtins.int
    @property
    def last9(self) -> global___AnnotationsConfig.Last9: ...
    def __init__(
        self,
        *,
        last9: global___AnnotationsConfig.Last9 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last9", b"last9"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last9", b"last9"]) -> None: ...

global___AnnotationsConfig = AnnotationsConfig

class ApplicationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RELEASE_CHANNELS_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_GROUPS_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_FIELD_NUMBER: builtins.int
    ANNOTATIONS_FIELD_NUMBER: builtins.int
    ALERTS_FIELD_NUMBER: builtins.int
    CAPABILITIES_FIELD_NUMBER: builtins.int
    CAPABILITY_INSTANCES_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def release_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig]: ...
    @property
    def release_channel_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelGroupGeneratorConfig]: ...
    @property
    def notifications(self) -> prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig: ...
    @property
    def annotations(self) -> global___AnnotationsConfig: ...
    @property
    def alerts(self) -> prodvana.proto.prodvana.workflow.integration_config_pb2.AlertingConfig:
        """deprecated"""
    @property
    def capabilities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.capability.capability_pb2.CapabilityConfig]:
        """deprecated"""
    @property
    def capability_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.capability.capability_pb2.CapabilityInstanceConfig]:
        """deprecated"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        release_channels: collections.abc.Iterable[prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig] | None = ...,
        release_channel_groups: collections.abc.Iterable[prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelGroupGeneratorConfig] | None = ...,
        notifications: prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig | None = ...,
        annotations: global___AnnotationsConfig | None = ...,
        alerts: prodvana.proto.prodvana.workflow.integration_config_pb2.AlertingConfig | None = ...,
        capabilities: collections.abc.Iterable[prodvana.proto.prodvana.capability.capability_pb2.CapabilityConfig] | None = ...,
        capability_instances: collections.abc.Iterable[prodvana.proto.prodvana.capability.capability_pb2.CapabilityInstanceConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alerts", b"alerts", "annotations", b"annotations", "notifications", b"notifications"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alerts", b"alerts", "annotations", b"annotations", "capabilities", b"capabilities", "capability_instances", b"capability_instances", "name", b"name", "notifications", b"notifications", "release_channel_groups", b"release_channel_groups", "release_channels", b"release_channels"]) -> None: ...

global___ApplicationConfig = ApplicationConfig
