# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/protection/builtins.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"prodvana/protection/builtins.proto\x12\x13prodvana.protection\x1a\x17validate/validate.proto\"\x85\x03\n\x1e\x43ommitDenylistProtectionConfig\x12\x1b\n\nrepository\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12U\n\x07\x63ommits\x18\x02 \x03(\x0b\x32\x44.prodvana.protection.CommitDenylistProtectionConfig.CommitDefinition\x1a\xee\x01\n\x10\x43ommitDefinition\x12\x19\n\x06\x63ommit\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x65\n\x05range\x18\x02 \x01(\x0b\x32J.prodvana.protection.CommitDenylistProtectionConfig.CommitDefinition.RangeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x1a\x43\n\x05Range\x12\x1d\n\x0cstart_commit\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1b\n\nend_commit\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x13\n\x0c\x63ommit_oneof\x12\x03\xf8\x42\x01\"G\n\nTimeWindow\x12\x15\n\x04\x64\x61ys\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05hours\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\n\n\x02tz\x18\x03 \x01(\t\"_\n\x1c\x41llowedTimesProtectionConfig\x12?\n\x07windows\x18\x01 \x03(\x0b\x32\x1f.prodvana.protection.TimeWindowB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x42OZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.protection.builtins_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protection'
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE.fields_by_name['start_commit']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE.fields_by_name['start_commit']._serialized_options = b'\372B\004r\002\020\001'
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE.fields_by_name['end_commit']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE.fields_by_name['end_commit']._serialized_options = b'\372B\004r\002\020\001'
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.oneofs_by_name['commit_oneof']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.oneofs_by_name['commit_oneof']._serialized_options = b'\370B\001'
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.fields_by_name['commit']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.fields_by_name['commit']._serialized_options = b'\372B\004r\002\020\001'
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.fields_by_name['range']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.fields_by_name['range']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMMITDENYLISTPROTECTIONCONFIG.fields_by_name['repository']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG.fields_by_name['repository']._serialized_options = b'\372B\004r\002\020\001'
  _TIMEWINDOW.fields_by_name['days']._options = None
  _TIMEWINDOW.fields_by_name['days']._serialized_options = b'\372B\004r\002\020\001'
  _TIMEWINDOW.fields_by_name['hours']._options = None
  _TIMEWINDOW.fields_by_name['hours']._serialized_options = b'\372B\004r\002\020\001'
  _ALLOWEDTIMESPROTECTIONCONFIG.fields_by_name['windows']._options = None
  _ALLOWEDTIMESPROTECTIONCONFIG.fields_by_name['windows']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _globals['_COMMITDENYLISTPROTECTIONCONFIG']._serialized_start=85
  _globals['_COMMITDENYLISTPROTECTIONCONFIG']._serialized_end=474
  _globals['_COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION']._serialized_start=236
  _globals['_COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION']._serialized_end=474
  _globals['_COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE']._serialized_start=386
  _globals['_COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE']._serialized_end=453
  _globals['_TIMEWINDOW']._serialized_start=476
  _globals['_TIMEWINDOW']._serialized_end=547
  _globals['_ALLOWEDTIMESPROTECTIONCONFIG']._serialized_start=549
  _globals['_ALLOWEDTIMESPROTECTIONCONFIG']._serialized_end=644
# @@protoc_insertion_point(module_scope)
