# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/program.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$prodvana/common_config/program.proto\x12\x16prodvana.common_config\x1a prodvana/common_config/env.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x17validate/validate.proto\"\xf5\x01\n\nPortConfig\x12\x19\n\x04port\x18\x01 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03(\x00\x12 \n\x0btarget_port\x18\x02 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03(\x00\x12\x10\n\x08\x65xternal\x18\x03 \x01(\x08\x12=\n\x08protocol\x18\x04 \x01(\x0e\x32+.prodvana.common_config.PortConfig.Protocol\x12\x0b\n\x03tls\x18\x05 \x01(\x08\"L\n\x08Protocol\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTP2\x10\x02\x12\x08\n\x04GRPC\x10\x03\x12\x07\n\x03TCP\x10\x04\"\x04\x08\x05\x10\x05*\x05HTTPS\"+\n\x0cResourceList\x12\x0e\n\x06memory\x18\x01 \x01(\t\x12\x0b\n\x03\x63pu\x18\x02 \x01(\t\"\x84\x01\n\x14ResourceRequirements\x12\x36\n\x08requests\x18\x01 \x01(\x0b\x32$.prodvana.common_config.ResourceList\x12\x34\n\x06limits\x18\x02 \x01(\x0b\x32$.prodvana.common_config.ResourceList\"A\n\tHttpProbe\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x19\n\x04port\x18\x02 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00\x12\x0b\n\x03tls\x18\x03 \x01(\x08\"\x1b\n\x08\x43mdProbe\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\t\"3\n\x08TcpProbe\x12\x19\n\x04port\x18\x01 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00\x12\x0c\n\x04host\x18\x02 \x01(\t\"\x8c\x02\n\x0bHealthCheck\x12\x31\n\x04http\x18\x01 \x01(\x0b\x32!.prodvana.common_config.HttpProbeH\x00\x12/\n\x03\x63md\x18\x02 \x01(\x0b\x32 .prodvana.common_config.CmdProbeH\x00\x12/\n\x03tcp\x18\x03 \x01(\x0b\x32 .prodvana.common_config.TcpProbeH\x00\x12(\n\x05\x64\x65lay\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x13\n\x0cprobe_config\x12\x03\xf8\x42\x01\"q\n\x11ImageRegistryInfo\x12\x1d\n\x15\x63ontainer_registry_id\x18\x01 \x01(\t\x12\x1a\n\x12\x63ontainer_registry\x18\x02 \x01(\t\x12!\n\x10image_repository\x18\x07 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"w\n\x0cImageDetails\x12J\n\rregistry_info\x18\x01 \x01(\x0b\x32).prodvana.common_config.ImageRegistryInfoB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1b\n\nidentifier\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x8c\x05\n\rProgramConfig\x12:\n\x04name\x18\x01 \x01(\tB,\xfa\x42)r\'\x10\x00\x18?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$\x12\r\n\x05image\x18\x02 \x01(\t\x12\x11\n\timage_tag\x18\x0e \x01(\t\x12\x46\n\x13image_registry_info\x18\t \x01(\x0b\x32).prodvana.common_config.ImageRegistryInfo\x12\x0b\n\x03\x63md\x18\x03 \x03(\t\x12\x12\n\nentrypoint\x18\x04 \x03(\t\x12\x64\n\x03\x65nv\x18\x05 \x03(\x0b\x32..prodvana.common_config.ProgramConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12?\n\tresources\x18\x06 \x01(\x0b\x32,.prodvana.common_config.ResourceRequirements\x12\x39\n\x0chealth_check\x18\x07 \x01(\x0b\x32#.prodvana.common_config.HealthCheck\x12@\n\x05ports\x18\x08 \x03(\x0b\x32\".prodvana.common_config.PortConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x19\n\x11template_complete\x18\n \x01(\x08\x12\x19\n\x11working_directory\x18\x0f \x01(\t\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01J\x04\x08\x0b\x10\x0cR\x06\x63ommit\"\x8a\x03\n\x1ePerReleaseChannelProgramConfig\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12u\n\x03\x65nv\x18\x02 \x03(\x0b\x32?.prodvana.common_config.PerReleaseChannelProgramConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12\r\n\x05image\x18\x03 \x01(\t\x12\x46\n\x13image_registry_info\x18\x04 \x01(\x0b\x32).prodvana.common_config.ImageRegistryInfo\x12\x11\n\timage_tag\x18\x05 \x01(\t\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.program_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _PORTCONFIG.fields_by_name['port']._options = None
  _PORTCONFIG.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003(\000'
  _PORTCONFIG.fields_by_name['target_port']._options = None
  _PORTCONFIG.fields_by_name['target_port']._serialized_options = b'\372B\010\032\006\030\377\377\003(\000'
  _HTTPPROBE.fields_by_name['port']._options = None
  _HTTPPROBE.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003 \000'
  _TCPPROBE.fields_by_name['port']._options = None
  _TCPPROBE.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003 \000'
  _HEALTHCHECK.oneofs_by_name['probe_config']._options = None
  _HEALTHCHECK.oneofs_by_name['probe_config']._serialized_options = b'\370B\001'
  _IMAGEREGISTRYINFO.fields_by_name['image_repository']._options = None
  _IMAGEREGISTRYINFO.fields_by_name['image_repository']._serialized_options = b'\372B\004r\002\020\001'
  _IMAGEDETAILS.fields_by_name['registry_info']._options = None
  _IMAGEDETAILS.fields_by_name['registry_info']._serialized_options = b'\372B\005\212\001\002\020\001'
  _IMAGEDETAILS.fields_by_name['identifier']._options = None
  _IMAGEDETAILS.fields_by_name['identifier']._serialized_options = b'\372B\004r\002\020\001'
  _PROGRAMCONFIG_ENVENTRY._options = None
  _PROGRAMCONFIG_ENVENTRY._serialized_options = b'8\001'
  _PROGRAMCONFIG.fields_by_name['name']._options = None
  _PROGRAMCONFIG.fields_by_name['name']._serialized_options = b'\372B)r\'\020\000\030?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$'
  _PROGRAMCONFIG.fields_by_name['env']._options = None
  _PROGRAMCONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _PROGRAMCONFIG.fields_by_name['ports']._options = None
  _PROGRAMCONFIG.fields_by_name['ports']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PERRELEASECHANNELPROGRAMCONFIG_ENVENTRY._options = None
  _PERRELEASECHANNELPROGRAMCONFIG_ENVENTRY._serialized_options = b'8\001'
  _PERRELEASECHANNELPROGRAMCONFIG.fields_by_name['name']._options = None
  _PERRELEASECHANNELPROGRAMCONFIG.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _PERRELEASECHANNELPROGRAMCONFIG.fields_by_name['env']._options = None
  _PERRELEASECHANNELPROGRAMCONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _globals['_PORTCONFIG']._serialized_start=156
  _globals['_PORTCONFIG']._serialized_end=401
  _globals['_PORTCONFIG_PROTOCOL']._serialized_start=325
  _globals['_PORTCONFIG_PROTOCOL']._serialized_end=401
  _globals['_RESOURCELIST']._serialized_start=403
  _globals['_RESOURCELIST']._serialized_end=446
  _globals['_RESOURCEREQUIREMENTS']._serialized_start=449
  _globals['_RESOURCEREQUIREMENTS']._serialized_end=581
  _globals['_HTTPPROBE']._serialized_start=583
  _globals['_HTTPPROBE']._serialized_end=648
  _globals['_CMDPROBE']._serialized_start=650
  _globals['_CMDPROBE']._serialized_end=677
  _globals['_TCPPROBE']._serialized_start=679
  _globals['_TCPPROBE']._serialized_end=730
  _globals['_HEALTHCHECK']._serialized_start=733
  _globals['_HEALTHCHECK']._serialized_end=1001
  _globals['_IMAGEREGISTRYINFO']._serialized_start=1003
  _globals['_IMAGEREGISTRYINFO']._serialized_end=1116
  _globals['_IMAGEDETAILS']._serialized_start=1118
  _globals['_IMAGEDETAILS']._serialized_end=1237
  _globals['_PROGRAMCONFIG']._serialized_start=1240
  _globals['_PROGRAMCONFIG']._serialized_end=1892
  _globals['_PROGRAMCONFIG_ENVENTRY']._serialized_start=1802
  _globals['_PROGRAMCONFIG_ENVENTRY']._serialized_end=1878
  _globals['_PERRELEASECHANNELPROGRAMCONFIG']._serialized_start=1895
  _globals['_PERRELEASECHANNELPROGRAMCONFIG']._serialized_end=2289
  _globals['_PERRELEASECHANNELPROGRAMCONFIG_ENVENTRY']._serialized_start=1802
  _globals['_PERRELEASECHANNELPROGRAMCONFIG_ENVENTRY']._serialized_end=1878
# @@protoc_insertion_point(module_scope)
