# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/protection/protection_reference.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.prodvana/protection/protection_reference.proto\x12\x13prodvana.protection\x1a\x1egoogle/protobuf/duration.proto\x1a\x17validate/validate.proto\x1a\'prodvana/common_config/parameters.proto\"\x9c\x04\n\x13ProtectionLifecycle\x12L\n\x0cpre_approval\x18\x01 \x01(\x0b\x32\x34.prodvana.protection.ProtectionLifecycle.PreApprovalH\x00\x12N\n\rpost_approval\x18\x03 \x01(\x0b\x32\x35.prodvana.protection.ProtectionLifecycle.PostApprovalH\x00\x12I\n\ndeployment\x18\x04 \x01(\x0b\x32\x33.prodvana.protection.ProtectionLifecycle.DeploymentH\x00\x12R\n\x0fpost_deployment\x18\x05 \x01(\x0b\x32\x37.prodvana.protection.ProtectionLifecycle.PostDeploymentH\x00\x1a\r\n\x0bPreApproval\x1a\x0e\n\x0cPostApproval\x1a\x0c\n\nDeployment\x1a\x88\x01\n\x0ePostDeployment\x12\x37\n\x14\x64\x65lay_check_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\x0e\x63heck_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x42\x10\n\tlifecycle\x12\x03\xf8\x42\x01\"\x9c\x01\n\x13ProtectionReference\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12:\n\nparameters\x18\x03 \x03(\x0b\x32&.prodvana.common_config.ParameterValueJ\x04\x08\x02\x10\x03R\x08\x61ttachedBOZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.protection.protection_reference_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protection'
  _PROTECTIONLIFECYCLE_POSTDEPLOYMENT.fields_by_name['check_duration']._options = None
  _PROTECTIONLIFECYCLE_POSTDEPLOYMENT.fields_by_name['check_duration']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _PROTECTIONLIFECYCLE.oneofs_by_name['lifecycle']._options = None
  _PROTECTIONLIFECYCLE.oneofs_by_name['lifecycle']._serialized_options = b'\370B\001'
  _PROTECTIONREFERENCE.fields_by_name['name']._options = None
  _PROTECTIONREFERENCE.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _globals['_PROTECTIONLIFECYCLE']._serialized_start=170
  _globals['_PROTECTIONLIFECYCLE']._serialized_end=710
  _globals['_PROTECTIONLIFECYCLE_PREAPPROVAL']._serialized_start=510
  _globals['_PROTECTIONLIFECYCLE_PREAPPROVAL']._serialized_end=523
  _globals['_PROTECTIONLIFECYCLE_POSTAPPROVAL']._serialized_start=525
  _globals['_PROTECTIONLIFECYCLE_POSTAPPROVAL']._serialized_end=539
  _globals['_PROTECTIONLIFECYCLE_DEPLOYMENT']._serialized_start=541
  _globals['_PROTECTIONLIFECYCLE_DEPLOYMENT']._serialized_end=553
  _globals['_PROTECTIONLIFECYCLE_POSTDEPLOYMENT']._serialized_start=556
  _globals['_PROTECTIONLIFECYCLE_POSTDEPLOYMENT']._serialized_end=692
  _globals['_PROTECTIONREFERENCE']._serialized_start=713
  _globals['_PROTECTIONREFERENCE']._serialized_end=869
# @@protoc_insertion_point(module_scope)
