# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/agent/agent_interaction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.environment import clusters_pb2 as prodvana_dot_environment_dot_clusters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/agent/agent_interaction.proto\x12\x0eprodvana.agent\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a#prodvana/environment/clusters.proto\"\"\n\x0cHeartbeatReq\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x0f\n\rHeartbeatResp\"\x95\x01\n\x17RecordNewUnknownPushReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1a\n\x18RecordNewUnknownPushResp\"\xc5\x01\n\x12RecordPushStartReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x33\n\x0fstart_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x15\n\x13RecordPushStartResp\"\x92\x01\n\x14RecordPushOngoingReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\"\x17\n\x15RecordPushOngoingResp\"\x82\x02\n\x15RecordPushCompleteReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x38\n\x04type\x18\x04 \x01(\x0e\x32*.prodvana.agent.RecordPushCompleteReq.Type\"3\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\x0f\n\x0bROLLED_BACK\x10\x02\"\x18\n\x16RecordPushCompleteResp\"\x94\x01\n\x16\x43onfirmPushApprovalReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\"+\n\x17\x43onfirmPushApprovalResp\x12\x10\n\x08\x61pproved\x18\x01 \x01(\x08\"_\n\x0cRecordPodReq\x12\x0b\n\x03pod\x18\x01 \x01(\x0c\x12.\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1e.prodvana.agent.InformerAction\x12\x12\n\nruntime_id\x18\x03 \x01(\t\"\x0f\n\rRecordPodResp\"1\n\rRecordPodsReq\x12\x0c\n\x04pods\x18\x01 \x03(\x0c\x12\x12\n\nruntime_id\x18\x02 \x01(\t\"\x10\n\x0eRecordPodsResp\"Y\n\x13RecordDeploymentReq\x12\x12\n\ndeployment\x18\x01 \x01(\x0c\x12.\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1e.prodvana.agent.InformerAction\"J\n\x14RecordDeploymentResp\x12\x32\n\x0epush_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"S\n\x10RecordRolloutReq\x12\x0f\n\x07rollout\x18\x01 \x01(\x0c\x12.\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1e.prodvana.agent.InformerAction\"G\n\x11RecordRolloutResp\x12\x32\n\x0epush_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"Q\n\x11ProxyAPIServerReq\x12\x14\n\nruntime_id\x18\x01 \x01(\tH\x00\x12\x0e\n\x04\x62lob\x18\x02 \x01(\x0cH\x00\x12\x0f\n\x07\x63onn_id\x18\x03 \x01(\tB\x05\n\x03msg\"\x8e\x01\n\x12ProxyAPIServerResp\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32\'.prodvana.agent.ProxyAPIServerResp.TypeH\x00\x12\x0e\n\x04\x62lob\x18\x02 \x01(\x0cH\x00\"(\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fPROXY_APISERVER\x10\x01\x42\x05\n\x03msg\"5\n\tDebugInfo\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x19\n\x11tcptraceroute_out\x18\x02 \x01(\t\"Q\n\x12ReportDebugInfoReq\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\'\n\x04info\x18\x02 \x01(\x0b\x32\x19.prodvana.agent.DebugInfo\"\x15\n\x13ReportDebugInfoResp\"~\n\x18ReportClusterMetadataReq\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12?\n\x10\x63luster_metadata\x18\x02 \x01(\x0b\x32%.prodvana.environment.ClusterMetadata\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\x1b\n\x19ReportClusterMetadataResp*1\n\x0eInformerAction\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\x32\xf1\t\n\x10\x41gentInteraction\x12J\n\tHeartbeat\x12\x1c.prodvana.agent.HeartbeatReq\x1a\x1d.prodvana.agent.HeartbeatResp\"\x00\x12h\n\x13\x43onfirmPushApproval\x12&.prodvana.agent.ConfirmPushApprovalReq\x1a\'.prodvana.agent.ConfirmPushApprovalResp\"\x00\x12k\n\x14RecordNewUnknownPush\x12\'.prodvana.agent.RecordNewUnknownPushReq\x1a(.prodvana.agent.RecordNewUnknownPushResp\"\x00\x12\\\n\x0fRecordPushStart\x12\".prodvana.agent.RecordPushStartReq\x1a#.prodvana.agent.RecordPushStartResp\"\x00\x12\x62\n\x11RecordPushOngoing\x12$.prodvana.agent.RecordPushOngoingReq\x1a%.prodvana.agent.RecordPushOngoingResp\"\x00\x12\x65\n\x12RecordPushComplete\x12%.prodvana.agent.RecordPushCompleteReq\x1a&.prodvana.agent.RecordPushCompleteResp\"\x00\x12J\n\tRecordPod\x12\x1c.prodvana.agent.RecordPodReq\x1a\x1d.prodvana.agent.RecordPodResp\"\x00\x12M\n\nRecordPods\x12\x1d.prodvana.agent.RecordPodsReq\x1a\x1e.prodvana.agent.RecordPodsResp\"\x00\x12_\n\x10RecordDeployment\x12#.prodvana.agent.RecordDeploymentReq\x1a$.prodvana.agent.RecordDeploymentResp\"\x00\x12V\n\rRecordRollout\x12 .prodvana.agent.RecordRolloutReq\x1a!.prodvana.agent.RecordRolloutResp\"\x00\x12]\n\x0eProxyAPIServer\x12!.prodvana.agent.ProxyAPIServerReq\x1a\".prodvana.agent.ProxyAPIServerResp\"\x00(\x01\x30\x01\x12\\\n\x0fReportDebugInfo\x12\".prodvana.agent.ReportDebugInfoReq\x1a#.prodvana.agent.ReportDebugInfoResp\"\x00\x12n\n\x15ReportClusterMetadata\x12(.prodvana.agent.ReportClusterMetadataReq\x1a).prodvana.agent.ReportClusterMetadataResp\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALBJZHgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.agent.agent_interaction_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZHgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/agent'
  _AGENTINTERACTION._options = None
  _AGENTINTERACTION._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _globals['_INFORMERACTION']._serialized_start=2324
  _globals['_INFORMERACTION']._serialized_end=2373
  _globals['_HEARTBEATREQ']._serialized_start=157
  _globals['_HEARTBEATREQ']._serialized_end=191
  _globals['_HEARTBEATRESP']._serialized_start=193
  _globals['_HEARTBEATRESP']._serialized_end=208
  _globals['_RECORDNEWUNKNOWNPUSHREQ']._serialized_start=211
  _globals['_RECORDNEWUNKNOWNPUSHREQ']._serialized_end=360
  _globals['_RECORDNEWUNKNOWNPUSHRESP']._serialized_start=362
  _globals['_RECORDNEWUNKNOWNPUSHRESP']._serialized_end=388
  _globals['_RECORDPUSHSTARTREQ']._serialized_start=391
  _globals['_RECORDPUSHSTARTREQ']._serialized_end=588
  _globals['_RECORDPUSHSTARTRESP']._serialized_start=590
  _globals['_RECORDPUSHSTARTRESP']._serialized_end=611
  _globals['_RECORDPUSHONGOINGREQ']._serialized_start=614
  _globals['_RECORDPUSHONGOINGREQ']._serialized_end=760
  _globals['_RECORDPUSHONGOINGRESP']._serialized_start=762
  _globals['_RECORDPUSHONGOINGRESP']._serialized_end=785
  _globals['_RECORDPUSHCOMPLETEREQ']._serialized_start=788
  _globals['_RECORDPUSHCOMPLETEREQ']._serialized_end=1046
  _globals['_RECORDPUSHCOMPLETEREQ_TYPE']._serialized_start=995
  _globals['_RECORDPUSHCOMPLETEREQ_TYPE']._serialized_end=1046
  _globals['_RECORDPUSHCOMPLETERESP']._serialized_start=1048
  _globals['_RECORDPUSHCOMPLETERESP']._serialized_end=1072
  _globals['_CONFIRMPUSHAPPROVALREQ']._serialized_start=1075
  _globals['_CONFIRMPUSHAPPROVALREQ']._serialized_end=1223
  _globals['_CONFIRMPUSHAPPROVALRESP']._serialized_start=1225
  _globals['_CONFIRMPUSHAPPROVALRESP']._serialized_end=1268
  _globals['_RECORDPODREQ']._serialized_start=1270
  _globals['_RECORDPODREQ']._serialized_end=1365
  _globals['_RECORDPODRESP']._serialized_start=1367
  _globals['_RECORDPODRESP']._serialized_end=1382
  _globals['_RECORDPODSREQ']._serialized_start=1384
  _globals['_RECORDPODSREQ']._serialized_end=1433
  _globals['_RECORDPODSRESP']._serialized_start=1435
  _globals['_RECORDPODSRESP']._serialized_end=1451
  _globals['_RECORDDEPLOYMENTREQ']._serialized_start=1453
  _globals['_RECORDDEPLOYMENTREQ']._serialized_end=1542
  _globals['_RECORDDEPLOYMENTRESP']._serialized_start=1544
  _globals['_RECORDDEPLOYMENTRESP']._serialized_end=1618
  _globals['_RECORDROLLOUTREQ']._serialized_start=1620
  _globals['_RECORDROLLOUTREQ']._serialized_end=1703
  _globals['_RECORDROLLOUTRESP']._serialized_start=1705
  _globals['_RECORDROLLOUTRESP']._serialized_end=1776
  _globals['_PROXYAPISERVERREQ']._serialized_start=1778
  _globals['_PROXYAPISERVERREQ']._serialized_end=1859
  _globals['_PROXYAPISERVERRESP']._serialized_start=1862
  _globals['_PROXYAPISERVERRESP']._serialized_end=2004
  _globals['_PROXYAPISERVERRESP_TYPE']._serialized_start=1957
  _globals['_PROXYAPISERVERRESP_TYPE']._serialized_end=1997
  _globals['_DEBUGINFO']._serialized_start=2006
  _globals['_DEBUGINFO']._serialized_end=2059
  _globals['_REPORTDEBUGINFOREQ']._serialized_start=2061
  _globals['_REPORTDEBUGINFOREQ']._serialized_end=2142
  _globals['_REPORTDEBUGINFORESP']._serialized_start=2144
  _globals['_REPORTDEBUGINFORESP']._serialized_end=2165
  _globals['_REPORTCLUSTERMETADATAREQ']._serialized_start=2167
  _globals['_REPORTCLUSTERMETADATAREQ']._serialized_end=2293
  _globals['_REPORTCLUSTERMETADATARESP']._serialized_start=2295
  _globals['_REPORTCLUSTERMETADATARESP']._serialized_end=2322
  _globals['_AGENTINTERACTION']._serialized_start=2376
  _globals['_AGENTINTERACTION']._serialized_end=3641
# @@protoc_insertion_point(module_scope)
